@@ -1,6 +1,7 @@
+"""Loaders for sequence labeling tasks."""
+
 from __future__ import annotations
 
-from explainaboard import TaskType
 from explainaboard.constants import FileType
 from explainaboard.loaders.file_loader import (
     CoNLLFileLoader,
@@ -10,31 +11,28 @@ from explainaboard.loaders.file_loader import (
     JSONFileLoader,
 )
 from explainaboard.loaders.loader import Loader
-from explainaboard.loaders.loader_registry import register_loader
 
 
-@register_loader(TaskType.chunking)
-@register_loader(TaskType.word_segmentation)
-@register_loader(TaskType.named_entity_recognition)
 class SeqLabLoader(Loader):
-    """
-    Validate and Reformat system output file with tsv format:
-    token \t true_tag \t predicted_tag
+    """Loader for the sequence labeling task.
 
     usage:
-        please refer to `test_loaders.py`
+        please refer to `loaders_test.py`
     """
 
     @classmethod
     def default_dataset_file_type(cls) -> FileType:
+        """See Loader.default_dataset_file_type."""
         return FileType.conll
 
     @classmethod
     def default_output_file_type(cls) -> FileType:
+        """See Loader.default_output_file_type."""
         return FileType.conll
 
     @classmethod
     def default_dataset_file_loaders(cls) -> dict[FileType, FileLoader]:
+        """See Loader.default_dataset_file_loaders."""
         field_names = ["tokens", "true_tags"]
         return {
             FileType.conll: CoNLLFileLoader(
@@ -53,6 +51,7 @@ class SeqLabLoader(Loader):
 
     @classmethod
     def default_output_file_loaders(cls) -> dict[FileType, FileLoader]:
+        """See Loader.default_output_file_loaders."""
         return {
             FileType.conll: CoNLLFileLoader([FileLoaderField(1, "pred_tags", str)]),
             FileType.json: JSONFileLoader(
