@@ -1,6 +1,5 @@
-from explainaboard import TaskType
+"""A list of table schemas.
 
-"""
 Each schema is a list of dictionary, which is used to instruct how to print bucket-level
 cases in the frontend table (the number of list denotes the number of table columns)
 Currently, the table schema is characterized by:
@@ -31,6 +30,10 @@ can get "answer"
 answer = system_output[A][B]
 """
 
+from __future__ import annotations
+
+from explainaboard import TaskType
+
 table_schemas = {}
 """Text Classification
 text | true_label | predicted_label
