@@ -5,8 +5,8 @@ import unittest
 from explainaboard.utils.typing_utils import narrow
 
 
-class TestTypingUtils(unittest.TestCase):
+class TypingUtilsTest(unittest.TestCase):
     def test_narrow(self):
-        a: str | int = 's'
+        a: str | int = "s"
         self.assertEqual(narrow(str, a), a)
         self.assertRaises(TypeError, lambda: narrow(int, a))
